{% extends "admin/cms/page/plugin/change_form.html" %}
{% load staticfiles %}

{% block extrahead %}
    {{ block.super }}
    <link type="text/css" rel="stylesheet" href="{% static "vendor/lightslider-master/dist/css/lightslider.min.css" %}" />

    <script src="{% static 'aldryn_bootstrap3/js/jquery.min.js' %}"></script>
    <script src="{% static "vendor/lightslider-master/dist/js/lightslider.min.js" %}"></script>
    <script src="{% static "aldryn_lightslider/js/lightslider.js" %}"></script>
{% endblock %}
