{% load cms_tags %}

<li>
    {% with image=instance.image %}
        {% if image %}
            {% if parent.number_of_concurrent_slides == 1 %}
                {% with image=instance.image srcset=lightslider.srcset %}{% include 'aldryn_lightslider/plugins/lightslider/standard/includes/image_fullscreen.html' %}{% endwith %}
            {% else %}
                {% with image=instance.image srcset=lightslider.srcset %}{% include 'aldryn_lightslider/plugins/lightslider/standard/includes/image.html' %}{% endwith %}
            {% endif %}
        {% endif %}
    {% endwith %}
    {% if instance.title %}
        <div class="lightslider-caption">
            {{ instance.title|safe }}
        </div>
    {% endif %}
</li>