HELPER_SETTINGS={
    'INSTALLED_APPS': [
        'djangocms_admin_style',
        'mptt',
		'cms',
		'menus',
		'sekizai',
		'cmsplugin_filer_file',
	    'cmsplugin_filer_folder',
	    'cmsplugin_filer_image',
	    'cmsplugin_filer_utils',
    ],
}