{% extends "aldryn_lightslider/plugins/lightslider/base.html" %}
{% load i18n cms_tags sekizai_tags staticfiles %}

{% block content_lightslider %}
{% with lightslider=instance %}
{# INFO: indicators #}
{#<ul class="lightslider-indicators">#}
{#    {% for slide in slides %}#}
{#        <li data-target="#js-lightslider-id-{{ instance.pk }}" data-slide-to="{{ forloop.counter0 }}"{% if forloop.first %} class="active"{% endif %}></li>#}
{#    {% endfor %}#}
{#</ul>#}

{# Wrapper for slides #}
{#<div class="lightslider-inner" role="listbox">#}
    {% for plugin in instance.child_plugin_instances %}
        {% render_plugin plugin %}
    {% endfor %}
{#</div>#}

{# INFO: controls #}
{#<a class="left lightslider-control" href="#js-lightslider-id-{{ instance.pk }}" role="button" data-slide="prev">#}
{#    <span class="fa fa-chevron-left glyphicon glyphicon-chevron-left" aria-hidden="true"></span>#}
{#    <span class="sr-only">{% trans "Previous" %}</span>#}
{#</a>#}
{#<a class="right lightslider-control" href="#js-lightslider-id-{{ instance.pk }}" role="button" data-slide="next">#}
{#    <span class="fa fa-chevron-right glyphicon glyphicon-chevron-right" aria-hidden="true"></span>#}
{#    <span class="sr-only">{% trans "Next" %}</span>#}
{#</a>#}
{% endwith %}
{% endblock content_lightslider %}
